@@ -1,5 +1,5 @@
 package Lab::Moose::Sweep;
-$Lab::Moose::Sweep::VERSION = '3.661';
+$Lab::Moose::Sweep::VERSION = '3.662';
 #ABSTRACT: Base class for high level sweeps
 
 # Step/List and Continuous sweep are implemented as subclasses
@@ -269,7 +269,10 @@ sub start {
         }
     }
     else {
-        $datafolder = Lab::Moose::datafolder( date_prefix => $date_prefix, time_prefix => $time_prefix );
+        $datafolder = Lab::Moose::datafolder(
+            date_prefix => $date_prefix,
+            time_prefix => $time_prefix
+        );
     }
 
     $self->_foldername( $datafolder->path() );
@@ -429,7 +432,7 @@ sub _start {
 
 }
 
-sub _validated_log {
+sub _validated_datafile_arg {
 
     # could only use validated_hash without caching
     my $self = shift;
@@ -443,7 +446,6 @@ sub _validated_log {
     if ( keys(%datafiles) < 1 ) {
         croak "no datafiles available in log method";
     }
-
     if ( not defined $handle ) {
         my @keys = keys(%datafiles);
         if ( @keys != 1 ) {
@@ -454,6 +456,11 @@ sub _validated_log {
 
     }
     $datafile = $datafiles{$handle};
+    return ( $self, $datafile, $handle, %args );
+}
+
+sub _validated_log {
+    my ( $self, $datafile, $handle, %args ) = _validated_datafile_arg(@_);
     $self->logged_datafiles()->{$handle} = 1;
     return ( $self, $datafile, %args );
 }
@@ -468,6 +475,22 @@ sub log_block {
     $datafile->log_block(%args);
 }
 
+sub _get_innermost_slave {
+    my $self = shift;
+    while ( defined $self->slave ) {
+        $self = $self->slave;
+    }
+    return $self;
+}
+
+sub refresh_plots {
+    my $self = shift;
+    $self = $self->_get_innermost_slave();
+    my ( $self2, $datafile, $handle, %args )
+        = _validated_datafile_arg( $self, @_ );
+    $datafile->refresh_plots(%args);
+}
+
 __PACKAGE__->meta->make_immutable();
 1;
 
@@ -483,7 +506,7 @@ Lab::Moose::Sweep - Base class for high level sweeps
 
 =head1 VERSION
 
-version 3.661
+version 3.662
 
 =head1 DESCRIPTION
 
